@@ -248,40 +248,37 @@ find_tab_num_at_pos (EphyNotebook *notebook, gint abs_x, gint abs_y)
 	GtkNotebook *nb = GTK_NOTEBOOK (notebook);
 	GtkWidget *page;
 
-	tab_pos = gtk_notebook_get_tab_pos (GTK_NOTEBOOK (notebook));
-
-	if (GTK_NOTEBOOK (notebook)->first_tab == NULL)
-	{
-		return AFTER_ALL_TABS;
-	}
-
 	/* For some reason unfullscreen + quick click can
 	   cause a wrong click event to be reported to the tab */
-	if (!is_in_notebook_window(notebook, abs_x, abs_y))
+	if (!is_in_notebook_window (notebook, abs_x, abs_y))
 	{
 		return NOT_IN_APP_WINDOWS;
 	}
 
+	tab_pos = gtk_notebook_get_tab_pos (nb);
+
 	while ((page = gtk_notebook_get_nth_page (nb, page_num)))
 	{
 		GtkWidget *tab;
+		GtkAllocation allocation;
 		gint max_x, max_y;
 		gint x_root, y_root;
 
 		tab = gtk_notebook_get_tab_label (nb, page);
 		g_return_val_if_fail (tab != NULL, -1);
 
-		if (!GTK_WIDGET_MAPPED (GTK_WIDGET (tab)))
+		if (!gtk_widget_get_mapped (GTK_WIDGET (tab)))
 		{
 			page_num++;
 			continue;
 		}
 
-		gdk_window_get_origin (GDK_WINDOW (tab->window),
+		gdk_window_get_origin (gtk_widget_get_window (tab),
 				       &x_root, &y_root);
 
-		max_x = x_root + tab->allocation.x + tab->allocation.width;
-		max_y = y_root + tab->allocation.y + tab->allocation.height;
+		gtk_widget_get_allocation (tab, &allocation);
+		max_x = x_root + allocation.x + allocation.width;
+		max_y = y_root + allocation.y + allocation.height;
 
 		if (((tab_pos == GTK_POS_TOP)
 		     || (tab_pos == GTK_POS_BOTTOM))
@@ -312,17 +309,18 @@ button_press_cb (EphyNotebook *notebook,
 
 	if (event->type == GDK_BUTTON_PRESS &&
 	    event->button == 3 &&
-		   (event->state & gtk_accelerator_get_default_mod_mask ()) == 0)
+	    (event->state & gtk_accelerator_get_default_mod_mask ()) == 0)
 	{
 		if (tab_clicked == -1)
 		{
-			/* consume event, so that we don't pop up the context menu when
-			 * the mouse if not over a tab label
+			/* Consume event so that we don't pop up the context
+			 * menu when the mouse is not over a tab label.
 			 */
 			return TRUE;
 		}
 
-		/* switch to the page the mouse is over, but don't consume the event */
+		/* Switch to the page where the mouse is over, but don't consume the
+		 * event. */
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), tab_clicked);
 	}
 
@@ -364,25 +362,29 @@ notebook_drag_data_received_cb (GtkWidget* widget,
 {
 	EphyWindow *window;
 	GtkWidget *notebook;
+	GdkAtom target;
+	const guchar *data;
 
-        if (selection_data->target == gdk_atom_intern_static_string ("GTK_NOTEBOOK_TAB"))
+	target = gtk_selection_data_get_target (selection_data);
+        if (target == gdk_atom_intern_static_string ("GTK_NOTEBOOK_TAB"))
                 return;
 
 	g_signal_stop_emission_by_name (widget, "drag_data_received");
 
 	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL)) return;
 
-	if (selection_data->length <= 0 || selection_data->data == NULL) return;
+	data = gtk_selection_data_get_data (selection_data);
+	if (gtk_selection_data_get_length (selection_data) <= 0 || data == NULL) return;
 
 	window = EPHY_WINDOW (gtk_widget_get_toplevel (widget));
 	notebook = ephy_window_get_notebook (window);
 
-	if (selection_data->target == gdk_atom_intern (EPHY_DND_URL_TYPE, FALSE))
+	if (target == gdk_atom_intern (EPHY_DND_URL_TYPE, FALSE))
 	{
 		char **split;
 
 		/* URL_TYPE has format: url \n title */
-		split = g_strsplit ((const gchar *)selection_data->data, "\n", 2);
+		split = g_strsplit ((const gchar *) data, "\n", 2);
 		if (split != NULL && split[0] != NULL && split[0][0] != '\0')
 		{
 			ephy_link_open (EPHY_LINK (notebook), split[0], embed,
@@ -390,7 +392,7 @@ notebook_drag_data_received_cb (GtkWidget* widget,
 		}
 		g_strfreev (split);
 	}
-	else if (selection_data->target == gdk_atom_intern (EPHY_DND_URI_LIST_TYPE, FALSE))
+	else if (target == gdk_atom_intern (EPHY_DND_URI_LIST_TYPE, FALSE))
 	{
 		char **uris;
 		int i;
@@ -543,7 +545,8 @@ sync_label (EphyWebView *view, GParamSpec *pspec, GtkWidget *label)
 	/* Set the tooltip on the label's parent (the tab label hbox),
 	 * so it covers all of the tab label.
 	 */
-	gtk_widget_set_tooltip_text (label->parent, title);
+	gtk_widget_set_tooltip_text (gtk_widget_get_parent (label),
+				     title);
 }
 
 static void
@@ -567,7 +570,7 @@ tab_label_style_set_cb (GtkWidget *hbox,
 
 	context = gtk_widget_get_pango_context (hbox);
 	metrics = pango_context_get_metrics (context,
-					     hbox->style->font_desc,
+					     gtk_widget_get_style (hbox)->font_desc,
 					     pango_context_get_language (context));
 
 	char_width = pango_font_metrics_get_approximate_digit_width (metrics);
@@ -651,7 +654,7 @@ build_tab_label (EphyNotebook *nb, EphyEmbed *embed)
 	g_object_set_data (G_OBJECT (hbox), "close-button", close_button);
 
 	/* Hook the label up to the tab properties */
-	view = EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed);
+	view = ephy_embed_get_web_view (embed);
 	sync_icon (view, NULL, GTK_IMAGE (icon));
 	sync_label (view, NULL, label);
 	sync_load_status (view, NULL, hbox);
@@ -677,6 +680,11 @@ ephy_notebook_set_show_tabs (EphyNotebook *nb,
 	update_tabs_visibility (nb, FALSE);
 }
 
+/**
+ * ephy_notebook_get_focused_pages:
+ *
+ * Return value: (transfer none):
+ **/
 GList *
 ephy_notebook_get_focused_pages (EphyNotebook *nb)
 {
@@ -739,7 +747,6 @@ ephy_notebook_add_tab (EphyNotebook *notebook,
 		gtk_notebook_set_current_page (gnotebook, position);
 		g_object_set_data (G_OBJECT (embed), "jump_to",
 				   GINT_TO_POINTER (jump_to));
-
 	}
 
 	return position;
@@ -804,7 +811,7 @@ ephy_notebook_remove (GtkContainer *container,
 	tab_label_icon = g_object_get_data (G_OBJECT (tab_label), "icon");
 	tab_label_label = g_object_get_data (G_OBJECT (tab_label), "label");
 
-	view = EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (tab_widget);
+	view = ephy_embed_get_web_view (EPHY_EMBED (tab_widget));
 
 	g_signal_handlers_disconnect_by_func
 		(view, G_CALLBACK (sync_icon), tab_label_icon);
