@@ -89,13 +89,12 @@ window_cmd_file_print_preview (GtkAction *action,
 			       EphyWindow *window)
 {
 	EphyEmbed *embed;
+	EphyWebView *view;
 
 	embed = ephy_embed_container_get_active_child 
-          (EPHY_EMBED_CONTAINER (window));
-	g_return_if_fail (EPHY_IS_EMBED (embed));
-
-	ephy_web_view_set_print_preview_mode (ephy_embed_get_web_view (embed), TRUE);
-	_ephy_window_set_print_preview (window, TRUE);
+	  (EPHY_EMBED_CONTAINER (window));
+	view = ephy_embed_get_web_view (embed);
+	ephy_web_view_show_print_preview (view);
 }
 
 void
@@ -103,12 +102,14 @@ window_cmd_file_print (GtkAction *action,
 		       EphyWindow *window)
 {
 	EphyEmbed *embed;
+	EphyWebView *view;
 
 	embed = ephy_embed_container_get_active_child 
           (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (EPHY_IS_EMBED (embed));
+	view = ephy_embed_get_web_view (embed);
 
-	webkit_web_view_execute_script (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed), "print();");
+	ephy_web_view_print (view);
 }
 
 void
@@ -328,6 +329,14 @@ window_cmd_file_save_as (GtkAction *action,
 	EphyEmbed *embed;
 	EphyFileChooser *dialog;
 
+	/* These all are needed in order to get the suggested filename */
+	char *suggested_filename;
+	const char *mimetype;
+	EphyWebView *view;
+	WebKitWebFrame *frame;
+	WebKitWebDataSource *data_source;
+	WebKitWebResource *web_resource;
+
 	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
@@ -337,6 +346,29 @@ window_cmd_file_save_as (GtkAction *action,
 					CONF_STATE_SAVE_DIR,
 					EPHY_FILE_FILTER_ALL_SUPPORTED);
 
+	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
+
+	view = ephy_embed_get_web_view (embed);
+	frame = webkit_web_view_get_main_frame (WEBKIT_WEB_VIEW (view));
+	data_source = webkit_web_frame_get_data_source (frame);
+	web_resource = webkit_web_data_source_get_main_resource (data_source);
+	mimetype = webkit_web_resource_get_mime_type (web_resource);
+
+	if ((g_ascii_strncasecmp (mimetype, "text/html", 9)) == 0)
+	{
+		/* Web Title will be used as suggested filename*/
+		suggested_filename = g_strconcat(ephy_web_view_get_title (view), ".html",NULL);
+	}
+	else
+	{
+		SoupURI *soup_uri = soup_uri_new (webkit_web_resource_get_uri (web_resource));
+		suggested_filename = g_path_get_basename (soup_uri->path);
+		soup_uri_free (soup_uri);
+	}
+
+	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), suggested_filename);
+	g_free (suggested_filename);
+
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (save_response_cb), embed);
 
@@ -1008,7 +1040,7 @@ window_cmd_help_about (GtkAction *action,
 			       "name", _("GNOME Web Browser"),
 			       "version", VERSION,
 			       "copyright", "Copyright © 2002–2004 Marco Pesenti Gritti\n"
-			                    "Copyright © 2003–2009 The GNOME Web Browser Developers",
+			                    "Copyright © 2003–2010 The GNOME Web Browser Developers",
 			       "artists", artists,
 			       "authors", authors,
 			       "comments", comments,
@@ -1152,7 +1184,7 @@ window_cmd_load_location (GtkAction *action,
 
 		ephy_link_open (EPHY_LINK (window), address,
 			        ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window)),
-				ephy_link_flags_from_current_event () | EPHY_LINK_ALLOW_FIXUP);
+				ephy_link_flags_from_current_event ());
 	}
 }
 
@@ -1161,7 +1193,44 @@ window_cmd_browse_with_caret (GtkAction *action,
 			      EphyWindow *window)
 {
 	gboolean active;
+	EphyEmbed *embed;
 
+	embed = ephy_embed_container_get_active_child 
+		(EPHY_EMBED_CONTAINER (window));
+	
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+
+	/* FIXME: perhaps a bit of a kludge; we check if there's an
+	 * active embed because we don't want to show the dialog on
+	 * startup when we sync the GtkAction with our GConf
+	 * preference */
+	if (active && embed)
+	{
+		GtkWidget *dialog;
+		int response;
+
+		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL,
+						 _("Enable caret browsing mode?"));
+
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("Pressing F7 turns caret browsing on or off. This feature "
+							    "places a moveable cursor in web pages, allowing you to move "
+							    "around with your keyboard. Do you want to enable caret browsing on?"));
+		gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Enable"), GTK_RESPONSE_ACCEPT);
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		gtk_widget_destroy (dialog);
+
+		if (response == GTK_RESPONSE_CANCEL)
+		{
+			gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), FALSE);
+			return;
+		}
+	}
+
 	eel_gconf_set_boolean (CONF_CARET_BROWSING_ENABLED, active);
 }
